@@ -56,7 +56,7 @@ html_theme_options = {
 htmlhelp_basename = "VWSPYTHONdoc"
 autoclass_content = "init"
 intersphinx_mapping = {
-    "python": ("https://docs.python.org/3.11", None),
+    "python": ("https://docs.python.org/3.12", None),
 }
 nitpicky = True
 warning_is_error = True
@@ -70,10 +70,6 @@ nitpick_ignore = [
 
 autoclass_content = "both"
 
-
-# Don't check anchors because many websites use #! for AJAX magic
-# http://sphinx-doc.org/config.html#confval-linkcheck_anchors
-linkcheck_anchors = False
 # Retry link checking to avoid transient network errors.
 linkcheck_retries = 5
 linkcheck_ignore = [
