@@ -8,6 +8,7 @@ import base64
 import json
 import time
 from datetime import date
+from http import HTTPStatus
 from typing import TYPE_CHECKING, BinaryIO
 from urllib.parse import urljoin
 
@@ -16,8 +17,10 @@ from requests import Response
 from vws_auth_tools import authorization_header, rfc_1123_date
 
 from vws.exceptions.custom_exceptions import (
+    OopsAnErrorOccurredPossiblyBadName,
+    ServerError,
     TargetProcessingTimeout,
-    UnknownVWSErrorPossiblyBadName,
+    TooManyRequests,
 )
 from vws.exceptions.vws_exceptions import (
     AuthenticationFailure,
@@ -154,16 +157,20 @@ class VWS:
             request_path: The path to the endpoint which will be used in the
                 request.
             expected_result_code: See
-                https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API.html#How-To-Interperete-VWS-API-Result-Codes
+                https://library.vuforia.com/web-api/cloud-targets-web-services-api#result-codes
 
         Returns:
             The response to the request made by `requests`.
 
         Raises:
-            ~vws.exceptions.UnknownVWSErrorPossiblyBadName: Vuforia returns an
-                HTML page with the text "Oops, an error occurred". This has
+            ~vws.exceptions.OopsAnErrorOccurredPossiblyBadName: Vuforia returns
+                an HTML page with the text "Oops, an error occurred". This has
                 been seen to happen when the given name includes a bad
                 character.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
             json.decoder.JSONDecodeError: The server did not respond with valid
                 JSON. This may happen if the server address is not a valid
                 Vuforia server.
@@ -178,7 +185,18 @@ class VWS:
         )
 
         if "Oops, an error occurred" in response.text:
-            raise UnknownVWSErrorPossiblyBadName
+            raise OopsAnErrorOccurredPossiblyBadName(response=response)
+
+        if (
+            response.status_code == HTTPStatus.TOO_MANY_REQUESTS
+        ):  # pragma: no cover
+            # The Vuforia API returns a 429 response with no JSON body.
+            raise TooManyRequests(response=response)
+
+        if (
+            response.status_code >= HTTPStatus.INTERNAL_SERVER_ERROR
+        ):  # pragma: no cover
+            raise ServerError(response=response)
 
         result_code = response.json()["result_code"]
 
@@ -209,7 +227,7 @@ class VWS:
     def add_target(
         self,
         name: str,
-        width: int | float,
+        width: float,
         image: BinaryIO,
         application_metadata: str | None,
         *,
@@ -219,7 +237,7 @@ class VWS:
         Add a target to a Vuforia Web Services database.
 
         See
-        https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API#How-To-Add-a-Target
+        https://library.vuforia.com/web-api/cloud-targets-web-services-api#add
         for parameter details.
 
         Args:
@@ -256,10 +274,14 @@ class VWS:
                 inactive.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
-            ~vws.exceptions.custom_exceptions.UnknownVWSErrorPossiblyBadName:
+            ~vws.exceptions.custom_exceptions.OopsAnErrorOccurredPossiblyBadName:
                 Vuforia returns an HTML page with the text "Oops, an error
                 occurred". This has been seen to happen when the given name
                 includes a bad character.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         image_data = _get_image_data(image=image)
         image_data_encoded = base64.b64encode(image_data).decode("ascii")
@@ -288,7 +310,7 @@ class VWS:
         Get a given target's target record from the Target Management System.
 
         See
-        https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API#How-To-Retrieve-a-Target-Record.
+        https://library.vuforia.com/web-api/cloud-targets-web-services-api#target-record.
 
         Args:
             target_id: The ID of the target to get details of.
@@ -306,6 +328,10 @@ class VWS:
                 does not match a target in the database.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         response = self._make_request(
             method="GET",
@@ -363,6 +389,10 @@ class VWS:
                 does not match a target in the database.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         start_time = time.monotonic()
         while True:
@@ -381,7 +411,7 @@ class VWS:
         List target IDs.
 
         See
-        https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API#How-To-Get-a-Target-List-for-a-Cloud-Database.
+        https://library.vuforia.com/web-api/cloud-targets-web-services-api#details-list.
 
         Returns:
             The IDs of all targets in the database.
@@ -394,6 +424,10 @@ class VWS:
                 known database.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         response = self._make_request(
             method="GET",
@@ -409,7 +443,7 @@ class VWS:
         Get a summary report for a target.
 
         See
-        https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API#How-To-Retrieve-a-Target-Summary-Report.
+        https://library.vuforia.com/web-api/cloud-targets-web-services-api#summary-report.
 
         Args:
             target_id: The ID of the target to get a summary report for.
@@ -427,6 +461,10 @@ class VWS:
                 does not match a target in the database.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         response = self._make_request(
             method="GET",
@@ -453,7 +491,7 @@ class VWS:
         Get a summary report for the database.
 
         See
-        https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API#How-To-Get-a-Database-Summary-Report.
+        https://library.vuforia.com/web-api/cloud-targets-web-services-api#summary-report.
 
         Returns:
             Details of the database.
@@ -466,6 +504,10 @@ class VWS:
                 known database.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         response = self._make_request(
             method="GET",
@@ -495,7 +537,7 @@ class VWS:
         Delete a given target.
 
         See
-        https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API#How-To-Delete-a-Target.
+        https://library.vuforia.com/web-api/cloud-targets-web-services-api#delete.
 
         Args:
             target_id: The ID of the target to delete.
@@ -512,6 +554,10 @@ class VWS:
                 target is in the processing state.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         self._make_request(
             method="DELETE",
@@ -525,7 +571,7 @@ class VWS:
         Get targets which may be considered duplicates of a given target.
 
         See
-        https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API.html#How-To-Check-for-Duplicate-Targets.
+        https://library.vuforia.com/web-api/cloud-targets-web-services-api#check.
 
         Args:
             target_id: The ID of the target to delete.
@@ -545,6 +591,10 @@ class VWS:
                 inactive.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         response = self._make_request(
             method="GET",
@@ -559,7 +609,7 @@ class VWS:
         self,
         target_id: str,
         name: str | None = None,
-        width: int | float | None = None,
+        width: float | None = None,
         image: io.BytesIO | None = None,
         active_flag: bool | None = None,
         application_metadata: str | None = None,
@@ -568,7 +618,7 @@ class VWS:
         Add a target to a Vuforia Web Services database.
 
         See
-        https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API#How-To-Add-a-Target
+        https://library.vuforia.com/web-api/cloud-targets-web-services-api#add
         for parameter details.
 
         Args:
@@ -604,6 +654,10 @@ class VWS:
                 inactive.
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
+            ~vws.exceptions.custom_exceptions.ServerError: There is an error
+                with Vuforia's servers.
+            ~vws.exceptions.custom_exceptions.TooManyRequests: Vuforia is rate
+                limiting access.
         """
         data: dict[str, str | bool | float | int] = {}
 
